$TITLE GTAP data v11 to Global SAM with Satellite Data
$OFFUPPER
$ONEMPTY

*############## 1. SET UP ################################################
$ontext
  THIS PROGRAMME - gtp_sam_11.gms IS SET UP FOR GTAP V11
  THE ASSOCIATED EXCEL FILE IS data_gtp_sam_11.xlsx
  
    USERS need to assign the SETGLOBAL statements to choose the year
          for which the GTAP SAM and satellite accounts are complied
          
    The INCLUDE file single_set.inc is used to remove quoted elements
         from the code.
         IF you use different labels for elements identifed in
            single_set.inc to those in the package you will need to
            update this file
$offtext

*~~~~~ SETGLOBAL assignments
* Assign the Excel workbook (this should work for all years in GTAP v 11)

$SETGLOBAL    xl_data   data_gtp_sam_11

* Assign the year for the directory with the GTAP data

$SETGLOBAL    year      GDX17

* Assign the name for the output GDX file

$SETGLOBAL    data_out  gtpdatav11_17

*############## 2. NOTES ON USING GTAP DATA #############################
$onfold

$onText
This programme was developed by Scott McDonald

 Scott McDonald
 Moncrieffe Road,
 Sheffield, S7 1HR, UK
 email:
    scott@cgemod.org.uk

Acknowledgements:
  When this programme was first developed (2004):
    Terrie Walmsley provided invaluable helpful advice about the GTAP model
        and GEMPACK.
    Helpful comments were provided by the referees for GTAP Tech Paper 22.
    Vitaly Kharitonov identified an error in the code.

This version works with GTAP version 11.

This version last checked 18th Jan 2024

Documentation for the SAM representation of GTAP data is in

Scott McDonald and Karen Thierfelder, (2024)
'Deriving a Global Social Accounting Matrix and Satellite Data from GTAP
 Databases', CGEMOD Technical Paper 15
(a revised version of Global Trade Analysis Project Technical Paper 22.
Center for Global Trade Analysis: Purdue University - www.gtap.org).

Copyright (c) 2024 Scott McDonald

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 4 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

A copy of the GNU GPL, gpl.txt, is included with the programme files.

Do NOT remove this notice if you redistribute this programme

If you use this programme you should acknowledge the source and not claim
authorship. Altered versions should be clearly distinguished from the original.
$offtext

$ontext
 
############### WARNING #################
  GTAP often makes seemingly minor changes to labels and names used for
  parameters between releases. Many of these are irrelevant to users of
  GEMPACK but can cause issues for GAMS users.

  For each new version of the GTAP database it is often necessary to
 'adjust' the programme and Excel workbook. Hence the many checks in this
  programme.

  We are not board members so can only produce a new version when we get
  access to new versions of the database.
$offtext

$ontext
*~~~~~~~~~~~~~~~~~ SOME NOTES ABOUT GTAP DATA IN GDX ~~~~~~

  I assume these comments also apply to GTAP data in HAR, but users need to
verify this for themselves.

  With GTAP 11, there has been an attempt by GTAP to allign definitions/
notation with that used in national accounts. It has not been succesful.
Those who understand the SNA need to be aware of the fact that terms used
by GTAP are NOT consistent with their use in national accounts.

  In the System of National Accounts (SNA) 2008 the terms 'basic' and 'purchaser'
prices have specific meanings. The use of these terms by GTAP is not
consistent with the SNA meanings, e.g.,
     MAKB(comm,acts,reg)    Post-tax make matrix at basic prices
     MAKS(comm,acts,reg)    Pre-tax make matrix
     
  In the SNA the SUPPLY matrix (also known as the MAKE matrix in earlier
version of the SNA) in the SUPPLY/MAKE matrix the transaction values (TVs)
for commodities produced by activities are valued at BASIC prices to which,
ignoring for now imports, are added net taxes on commodities and domestic
trade and transport margins to derive domestic supply at 'purchaser' prices. 
    
$offtext
$offFold
* This file is outdated and awaiting revision
$INCLUDE include\gtp_data_notes_11.inc

*############## 2. DECLARING SETS AND PARAMETERS FOR THIS PROGRAMME #######
$onfold

SETS

* These sets come from the basic GTAP database

 acts                 Activities

 comm                 Commodities
 endw                 Endowments
 
 marg                 Margin commodities
 
 c                    Countries
 reg                  Regions
 
 map_reg_c(reg,c)     Mapping from countries to regions
 
 tartype(*)           Tariff types
 
 samac                Generic account for GTAP accounts
 
* Energy

 erg(comm)            Energy commodities
 fuel(erg)            Fuel types

* Emissions

 em                   emissions
 ghg(em)              Greehouse gases
 ghgn(em)             NON Greehouse gases
 fgas(em)             F Gases
 
  
 emnco2(em)          Emissions other than co2   
 ghgnco2(ghg)        Set of greenhouse gases other than co2
 

 lu_cat              Land Use category
 lu_subcat           Land Use sub category

 ar        IPCC Assesement reports /
 ar2        IPPC AR2
 ar4        IPCC AR4
 ar5        IPCC AR5 

/

 ;         
  
ALIAS (reg,regp,src,dst) ;

Sets
* These sets are user assigned
 
 ss                   GTAP SAMG Accounts
 mcc(ss)              Imported Commodities
 dcc(ss)              Domestic Commodities
 cc(ss)               Aggregate commodities
 aa(ss)               Activities

 ff(ss)               Factors
 ll(ff)               Labour

 ttm(ss)              Import duties and Ad valorem equivalent Import duties
 ttms(ss)             Specific Import duties                               
 tte(ss)              Export taxes                                         
 tts(ss)
 ttsm(ss)             Sales Taxes on imported goods and services
 ttsd(ss)             Sales Taxes on domestic goods and services
 ttff(ss)             Taxes on Factors                          

 ootpm(ss)            Other trade and transport costs         
 wwtpm(ss)            Water trade and transport costs        
 aatpm(ss)            Air trade and transport costs          
 vvst(ss)             Exports of trade and transport services      

 ii(ss)               Investment

 ww(ss)               Rest of the World
 rr                   Regions
 
* Energy commodities and taxes

 cc_e(cc)          Aggregate energy commodities
 mcc_e(mcc)        Imported energy Commodities
 dcc_e(dcc)        Domestic energy Commodities

 tts_e(ss)         Sales Taxes on aggregate ENERGY goods and services
 ttsd_e(ttsd)      Sales Taxes on imported ENERGY goods and services
 ttsm_e(ttsm)      Sales Taxes on domestic ENERGY goods and services
 
* Mapping sets

 map_mcc_comm(mcc,comm)   Map to import commodities from comm
 map_dcc_comm(dcc,comm)   Map to domestic commodities from comm
 map_cc_comm(cc,comm)     Map to aggregate commodities from comm
 map_cc_mcc(cc,mcc)       Map to aggregate from import commodities
 map_cc_dcc(cc,dcc)       Map to aggregate from domestic commodities
 map_aa_acts(aa,acts)     Map to activities from at
 map_ff_endw(ff,endw)     Map to factors from endw

 
 map_ttm_reg(ttm,reg)     Map to ad val import duties from regions
 map_ttms_reg(ttms,reg)   Map to specific import duties from regions
 map_tte_reg(tte,reg)     Map to export taxes from regions
 
 map_ww_reg(ww,reg)       Map to trade partners from regions
 map_reg_reg(reg,reg)     Map regions to regions
 
 map_rr_reg(rr,reg)       Map to region rr from region reg
 
 map_ttsm_comm(ttsm,comm) Map to import sales taxes from comm
 map_ttsd_comm(ttsd,comm) Map to domestic sales taxes from comm
 map_ttff_endw(ttff,endw) Map to factor use taxes from endw
 
 map_ootpm_reg(ootpm,reg) Map to other import margins from regions
 map_wwtpm_reg(wwtpm,reg) Map to water import margins from regions
 map_aatpm_reg(aatpm,reg) Map to air import margins from regions
 
 map_ww_wwtpm(ww,wwtpm)    Map to trade partners from water import margins
 map_ww_aatpm(ww,aatpm)    Map to trade partners from air import margins
 map_ww_ootpm(ww,ootpm)    Map to trade partners from other import margins

 ssn(ss)                  SS less totals

 ;
$offfold 

*############## 4. LOADING THE GTAP DATA IN GDX ##########################
$onfold
$ontext
   GTAP now make a their database available in GDX format for GAMS users,
 this has, at least in part, been influenced by GAMS decision to
 discontinue HAR2GDX
 
   Unfortunately, the GDX release does not include the GTAP database in
 a SAM format, whereas using the HAR format database users can readily
 generate a SAM for the whole global database or an aggregation.
 In the past we used HAR2GDX to transform the HAR version of a SAM into
 a GDX fomrat.

   In later versions it is planned to create the requisite sets from the
 GDX data files. BUT GTAP sets data have used, in some versions, the
 SAME labels for some regions and sectors. This can cause ordering
 problems in GAMS so it is, for now, less error prone to define
 many of the sets and maps in Excel

$offtext

*---- 1b. All from GDX and excel are assigned here

$GDXIN GTP_data\%year%\GSDFDAT.gdx

* Sets
$LOADdc acts c comm endw marg reg
 
$LOADdc map_reg_c = mapc
 
$LOADdc tartype

$GDXIN

ALIAS (comm,commp) ;


* Converting Excel sets data to GDX
$CALL "GDXXRW i=%xl_data%.xlsx o=data_in.gdx INDEX=LAYOUT!A4 trace=3"
$if errorLevel 1 $abort problems with GDXXRW


$GDXIN data_in.gdx

$LOADdc ss mcc dcc cc aa ff ll
$LOADdc ttm ttms tte
$LOADdc ttsm ttsd
$LOADdc ttff
$LOADdc ootpm wwtpm aatpm vvst
$LOADdc ww
$LOADdc ii

$LOADdc cc_e mcc_e dcc_e tts_e ttsd_e ttsm_e

$LOADdc rr

$LOAD samac

$LOADdc map_mcc_comm map_dcc_comm map_cc_comm map_cc_mcc map_cc_dcc map_aa_acts map_ff_endw  map_ww_reg
$LOADdc map_ttm_reg map_ttms_reg map_tte_reg
$LOADdc map_ttsm_comm  map_ttsd_comm map_ttff_endw 
$LOADdc map_ootpm_reg map_wwtpm_reg map_aatpm_reg map_reg_reg map_rr_reg
$LOADdc map_ww_ootpm map_ww_wwtpm map_ww_aatpm

$LOADdc erg em ghg ghgn fgas lu_cat lu_subcat

$GDXIN

* Other Sets

 fuel(erg)      = YES ;
 fuel("ely")    = NO ;

 emnco2(em)     = YES ;
 emnco2("co2")  = NO ;
 
 ghgnco2(ghg)   = YES ;
 ghgnco2("co2") = NO ;
 
 ;

* SAM Accounts excluding totals
 ssn(ss)       = YES ;
 ssn("tots")   = NO ;

ALIAS (ss,ssp), (ssn,ssnp),(reg,regp,src,dst), (mcc,mccp), (dcc,dccp), (cc,ccp), (aa,aap), (rr,rrp) ;

$offfold
*~~~~ Singleton Sets

$INCLUDE  include\single_set.inc

*############## 5. DECLARING & ASSIGNING TRANSACTION PARAMETERS FROM GTAP #######
$onfold

Parameters
 EVFB(endw,acts,reg)    Primary factor purchases by firms at basic prices
 EVFP(endw,acts,reg)    Primary factor purchases at purchasers prices
 EVOS(endw,acts,reg)    After (income) tax value of endowment supply
 FBEP(endw,acts,reg)    Gross factor-based subsidy payments
 FTRV(endw,acts,reg)    Gross factor employment tax revenue

 MAKB(comm,acts,reg)    Post-tax make matrix at basic prices
 MAKS(comm,acts,reg)    Pre-tax make matrix
          
 SAVE(reg)              Saving by region

 POP(reg)               Population

 VCIF(comm,src,dst)     Imports at CIF prices
 VDEP(reg)              Capital depreciation
 VDFB(comm,acts,reg)    Domestic purchases by firms at basic prices
 VDFP(comm,acts,reg)    Domestic purchases by firms at purchasers prices
 VDGB(comm,reg)         Domestic purchases by government at basic prices
 VDGP(comm,reg)         Domestic purchases by government at purchasers prices
 VDIB(comm,reg)         Domestic purchases by investment at basic prices
 VDIP(comm,reg)         Domestic purchases by investment at purchasers prices
 VDPP(comm,reg)         Domestic purchases by households at purchasers prices
 VDPB(comm,reg)         Domestic purchases by households at basic prices
 VFOB(comm,src,dst)     Non-margin exports at FOB prices
 VKB(reg)               Capital stock
 VMFB(comm,acts,reg)    Import purchases by firms at basic prices
 VMFP(comm,acts,reg)    Import purchases by firms at purchasers prices
 VMGB(comm,reg)         Import purchases by government at basic prices
 VMGP(comm,reg)         Import purchases by government at purchasers prices
 VMIB(comm,reg)         Import purchases by investment at basic prices
 VMIP(comm,reg)         Import purchases by investment at purchasers prices
 VMPB(comm,reg)         Import purchases by households at basic prices
 VMPP(comm,reg)         Import purchases by households at purchasers prices
 VMSB(comm,src,dst)     Imports at basic prices
 VMTS(tartype,comm,src,dst) Import tariff revenue by type of tariffs paid
 VST(comm,reg)          Margin exports at basic prices
 VTWR(comm,comm,src,dst)    Margin usage by commodity source and destination at basic prices
 VXSB(comm,src,dst)    Non-margin exports at basic prices

 ;

$GDXIN GTP_data\%year%\GSDFDAT.gdx

* Sets
$LOADdc EVFB EVFP EVOS FBEP FTRV

$LOADdc MAKB MAKS
     
$LOADdc SAVE POP

$LOADdc VCIF VDEP VDFB VDFP VDGB VDGP VDIB VDIP VDPP VDPB
$LOADdc VFOB VKB VMFB VMFP VMGB VMGP VMIB VMIP VMPB VMPP
$LOADdc VMSB VMTS VST VTWR VXSB

$GDXIN

$offfold

*############## 6. DECLARING PARAMETERS FOR USE IN THIS PROGRAMME #######

Parameter
 SAM_gtp(ss,ss,reg)         Global GTAP SAMG 
 ;

*############## 7. CREATING THE GLOBAL SAM ###########################

$onFold

*#### Import commodity income components

* Import Intermediate Use matrices (1:3)

 SAM_gtp(mcc,aa,reg)      = SUM{(comm,acts)$[map_mcc_comm(mcc,comm)
                                 $map_aa_acts(aa,acts)],
                                  VMFB(comm,acts,reg)} ;

* Household import demand vectors (1:6)

 SAM_gtp(mcc,h_h,reg)   = SUM{comm$map_mcc_comm(mcc,comm),
                           VMPB(comm,reg)} ;

* Government import demand vectors (1:13)

 SAM_gtp(mcc,g_t,reg)   = SUM{comm$map_mcc_comm(mcc,comm),
                           VMGB(comm,reg)} ;

* Investment import demand vectors (1:14)

 SAM_gtp(mcc,i_is,reg)   = SUM{comm$map_mcc_comm(mcc,comm),
                              VMIB(comm,reg)} ;

*#### Domestic commodity income components

* Domestic Intermediate Use matrices (2:3)

 SAM_gtp(dcc,aa,reg)      = SUM{(comm,acts)$[map_dcc_comm(dcc,comm)
                                 $map_aa_acts(aa,acts)],
                                  VDFB(comm,acts,reg)} ;
                          
* Household Domestic demand vectors (1:6)

 SAM_gtp(dcc,h_h,reg)   = SUM{comm$map_dcc_comm(dcc,comm),
                             VDPB(comm,reg)} ;

* Government Domestic demand vectors (1:13)

 SAM_gtp(dcc,g_t,reg)   = SUM{comm$map_dcc_comm(dcc,comm),
                             VDGB(comm,reg)} ;

* Investment Domestic demand vectors (1:14)

 SAM_gtp(dcc,i_is,reg)   = SUM{comm$map_dcc_comm(dcc,comm),
                               VDIB(comm,reg)} ;
                        
* Export demand matrices
* Export of transport services (2:16)

 SAM_gtp(d_wtm,vst_o,reg)     = VST(v_otm,reg) ;
 SAM_gtp(d_otm,vst_w,reg)     = VST(v_wtm,reg) ;
 SAM_gtp(d_atm,vst_a,reg)     = VST(v_atm,reg) ;
 
* Exports of Goods and Services (2:17)
                             
 SAM_gtp(dcc,ww,reg)      = SUM{[comm,dst]$[map_dcc_comm(dcc,comm)
                                $map_ww_reg(ww,dst)],
                                 VFOB(comm,reg,dst)} ;

*#### Activity Income

* Make Matrix (3:2)

 SAM_gtp(aa,dcc,reg)    = SUM{[comm,acts]$[map_dcc_comm(dcc,comm)
                                $map_aa_acts(aa,acts)],
                                   MAKB(comm,acts,reg)} ;                       
                                 
*#### Factor Income

* Factor demands by activities (4:3)

 SAM_gtp(ff,aa,reg)        = SUM{[endw,acts]$[map_ff_endw(ff,endw)
                                  $map_aa_acts(aa,acts)],
                                   EVFB(endw,acts,reg)} ;

*#### Indirect Tax Receipts for INDTAX(r) in GTAP model

*~~~ Import Duty Income (7:1)

* Ad valorem import duties

 SAM_gtp(ttm,mcc,reg)   = SUM{[comm,src]$[map_mcc_comm(mcc,comm)
                                 $map_ttm_reg(ttm,src)],
                                  VMTS(ad_val,comm,src,reg)} ;
                         
* Specific import duties (7:1)

 SAM_gtp(ttms,mcc,reg)   = SUM{[comm,src]$[map_mcc_comm(mcc,comm)
                                $map_ttms_reg(ttms,src)],
                                 VMTS(specif,comm,src,reg)} ;                   
                         
*# Import Sales Taxes

* Intermediate Inputs (8:3)

 SAM_gtp(ttsm,aa,reg)     = SUM{[comm,acts]$[map_ttsm_comm(ttsm,comm)
                                $map_aa_acts(aa,acts)],
                                 [VMFP(comm,acts,reg) - VMFB(comm,acts,reg)]} ;
                                 
* Household Demand (8:6)

 SAM_gtp(ttsm,h_h,reg)  = SUM{comm$map_ttsm_comm(ttsm,comm),
                          [VMPP(comm,reg) - VMPB(comm,reg)]} ;

* Government Demand (8:13)

 SAM_gtp(ttsm,g_t,reg)  = SUM{comm$map_ttsm_comm(ttsm,comm),
                          [VMGP(comm,reg) - VMGB(comm,reg)]} ;

* Investment Demand (8:14)

 SAM_gtp(ttsm,i_is,reg)  = SUM{comm$map_ttsm_comm(ttsm,comm),
                          [VMIP(comm,reg) - VMIB(comm,reg)]} ;

*# Domestic Sales Taxes

* Intermediate Inputs (9:3)

 SAM_gtp(ttsd,aa,reg)     = SUM{[comm,acts]$[map_ttsd_comm(ttsd,comm)
                                 $map_aa_acts(aa,acts)],
                                  [VDFP(comm,acts,reg) - VDFB(comm,acts,reg)]} ;
                                  
* Household Demand (9:6)

 SAM_gtp(ttsd,h_h,reg)  = SUM{comm$map_ttsd_comm(ttsd,comm),
                              [VDPP(comm,reg) - VDPB(comm,reg)]} ;

* Government Demand (9:13)

 SAM_gtp(ttsd,g_t,reg)  = SUM{comm$map_ttsd_comm(ttsd,comm),
                              [VDGP(comm,reg) - VDGB(comm,reg)]} ;

* Investment Demand (9:14)

 SAM_gtp(ttsd,i_is,reg)  = SUM{comm$map_ttsd_comm(ttsd,comm),
                              [VDIP(comm,reg) - VDIB(comm,reg)]} ;

* Factor taxes paid by activities (10:3)

 SAM_gtp(ttff,aa,reg)  = SUM{[endw,acts]$[map_ttff_endw(ttff,endw)
                             $map_aa_acts(aa,acts)],
                               [EVFP(endw,acts,reg) -  EVFB(endw,acts,reg)]} ;
                         
* Production taxes paid by activities (11:3)

 SAM_gtp(a_tax,aa,reg)  = SUM{acts$map_aa_acts(aa,acts),
                           [SUM(comm,(MAKB(comm,acts,reg) - MAKS(comm,acts,reg)))]} ;
                           
* Income taxes paid by factors

 SAM_gtp(d_tax,ff,reg)  = SUM[aa,SAM_gtp(ff,aa,reg)]
                              - SUM{acts,SUM[endw$map_ff_endw(ff,endw),
                                       EVOS(endw,acts,reg)]} ;
                                       
* Export taxes (7:2)

 SAM_gtp(tte,dcc,reg)    = SUM{[comm,dst]$[map_dcc_comm(dcc,comm)
                               $map_tte_reg(tte,dst)],
                                 [VFOB(comm,reg,dst) - VXSB(comm,reg,dst)]} ;
          
* #### Regional Household Accounts

* ~~~ Components of Regional Household Income

* Factor Incomes AFTER depreciation and income taxes(5:4)

 SAM_gtp(reg_h,ff,reg)    = SUM{acts,SUM[endw$map_ff_endw(ff,endw), EVOS(endw,acts,reg)]} ;
                               
 SAM_gtp(reg_h,f_k,reg)   = SAM_gtp(reg_h,f_k,reg) - VDEP(reg) ;

* Import duties and export taxes (5:7)

 SAM_gtp(reg_h,ttm,reg)   = SUM(mcc,SAM_gtp(ttm,mcc,reg))  ;
 SAM_gtp(reg_h,ttms,reg)  = SUM(mcc,SAM_gtp(ttms,mcc,reg))  ;

 SAM_gtp(reg_h,tte,reg)   = SUM(dcc,SAM_gtp(tte,dcc,reg)) ;

* Domestic Sales taxes (5:8)

 SAM_gtp(reg_h,ttsd,reg)  = SUM(aa, SAM_gtp(ttsd,aa,reg))
                              + SAM_gtp(ttsd,h_h,reg)
                              + SAM_gtp(ttsd,g_t,reg)
                              + SAM_gtp(ttsd,i_is,reg) ;

* Import Sales taxes (5:9)

 SAM_gtp(reg_h,ttsm,reg)  = SUM(aa,SAM_gtp(ttsm,aa,reg))
                              + SAM_gtp(ttsm,h_h,reg)
                              + SAM_gtp(ttsm,g_t,reg)
                              + SAM_gtp(ttsm,i_is,reg) ;

* Production Taxes (5:11)

 SAM_gtp(reg_h,a_tax,reg)  = SUM(aa,SAM_gtp(a_tax,aa,reg)) ;

* Factor Use Taxes

 SAM_gtp(reg_h,ttff,reg)   = SUM(aa,SAM_gtp(ttff,aa,reg)) ;

* Direct/Income taxes on Factors

 SAM_gtp(reg_h,d_tax,reg)   =  SUM[ff,SAM_gtp(d_tax,ff,reg)] ;

* ~~~ Regional Household Expenditures

* Income of Private Households (6:5)

 SAM_gtp(h_h,reg_h,reg) = SUM(mcc,SAM_gtp(mcc,h_h,reg))
                              + SUM(ttsm,SAM_gtp(ttsm,h_h,reg))
                              + SUM(dcc,SAM_gtp(dcc,h_h,reg))
                              + SUM(ttsd,SAM_gtp(ttsd,h_h,reg))  ;

* Income of Government (13:5)
 SAM_gtp(g_t,reg_h,reg) = SUM(mcc,SAM_gtp(mcc,g_t,reg))
                              + SUM(ttsm,SAM_gtp(ttsm,g_t,reg))
                              + SUM(dcc,SAM_gtp(dcc,g_t,reg))
                              + SUM(ttsd,SAM_gtp(ttsd,g_t,reg))  ;
 
*#### Rest of World

* Import Margin Matrices (15:1)


 SAM_gtp(ootpm,mcc,reg)    = SUM{[comm,src,dst]$[map_mcc_comm(mcc,comm)
                                    $map_ootpm_reg(ootpm,src)
                                    $map_reg_reg(reg,dst)],
                                     VTWR(v_otm,comm,src,dst)} ;

                                  
 SAM_gtp(wwtpm,mcc,reg)    = SUM{[comm,src,dst]$[map_mcc_comm(mcc,comm)
                                    $map_wwtpm_reg(wwtpm,src)
                                    $map_reg_reg(reg,dst)],
                                     VTWR(v_wtm,comm,src,dst)} ;
                                  
 SAM_gtp(aatpm,mcc,reg)    = SUM{[comm,src,dst]$[map_mcc_comm(mcc,comm)
                                    $map_aatpm_reg(aatpm,src)
                                    $map_reg_reg(reg,dst)],
                                     VTWR(v_atm,comm,src,dst)} ;
*## Import Supply Matrices (16:1)map

* Indirect Method using Exports fob

Parameter
 Imports_fob(ss,ss,reg)        Imporst valued fob
 Imports_cif(ss,ss,reg)        Imports valued cif
 Imports_cif_calc(ss,ss,reg)   Calculated imports valued cif
 
 ;
 
 Imports_fob(ww,mcc,reg)       = SUM{[comm,src,dst]$[map_mcc_comm(mcc,comm)
                                      $map_ww_reg(ww,src)
                                      $map_reg_reg(reg,dst)],
                                        VFOB(comm,src,dst)} ;                              

 SAM_gtp(ww,mcc,reg)       = SUM{[comm,src,dst]$[map_mcc_comm(mcc,comm)
                                      $map_ww_reg(ww,src)
                                      $map_reg_reg(reg,dst)],
                                        VFOB(comm,src,dst)} ;
                                  
 Imports_cif_calc(ww,mcc,reg) = SAM_gtp(ww,mcc,reg) 
                                + SUM[ootpm$map_ww_ootpm(ww,ootpm),SAM_gtp(ootpm,mcc,reg)]                                  
                                + SUM[wwtpm$map_ww_wwtpm(ww,wwtpm),SAM_gtp(wwtpm,mcc,reg)]                                  
                                + SUM[aatpm$map_ww_aatpm(ww,aatpm),SAM_gtp(aatpm,mcc,reg)]   ;                               


$ontext
*~~~ Using VCIF ~~~~~~
 Imports_cif(ww,mcc,reg)  = SUM{[comm,dst]
                             $[map_mcc_comm(mcc,comm)
                             $map_ww_reg(ww,dst)],
                             VCIF(comm,reg,dst)} ;
                           
 Imports_fob(ww,mcc,reg)  = SUM{[comm,dst]
                             $[map_mcc_comm(mcc,comm)
                             $map_ww_reg(ww,dst)],
                             [VCIF(comm,reg,dst) - SUM(commp,VTWR(commp,comm,reg,dst))]} ;
                           
$offtext


* Expenditures on transport services

 SAM_gtp(vst_o,ootpm,reg)  = SUM(mcc,SAM_gtp(ootpm,mcc,reg)) ;
 SAM_gtp(vst_w,wwtpm,reg)  = SUM(mcc,SAM_gtp(wwtpm,mcc,reg)) ;
 SAM_gtp(vst_a,aatpm,reg)  = SUM(mcc,SAM_gtp(aatpm,mcc,reg)) ;

*### Investment Savings Account Balances

* Depreciation charges (14:4)

 SAM_gtp(i_is,f_k,reg) = VDEP(reg) ;

* Trade Account balance for trade in transport services

 SAM_gtp(i_is,vst_o,reg)  = SUM((mcc,ootpm),SAM_gtp(ootpm,mcc,reg))
                                  - SUM(dcc,SAM_gtp(dcc,vst_o,reg)) ;

 SAM_gtp(i_is,vst_w,reg)  = SUM((mcc,wwtpm),SAM_gtp(wwtpm,mcc,reg))
                                  - SUM(dcc,SAM_gtp(dcc,vst_w,reg)) ;

 SAM_gtp(i_is,vst_a,reg)  = SUM((mcc,aatpm),SAM_gtp(aatpm,mcc,reg))
                                  - SUM(dcc,SAM_gtp(dcc,vst_a,reg)) ;

* Trade Account balances by trade partner on commodity trade

 SAM_gtp(i_is,ww,reg)       = SUM(mcc,SAM_gtp(ww,mcc,reg))
                                - SUM[dcc,SAM_gtp(dcc,ww,reg)] ;
                                
* Domestic Savings (14:5)
$ontext
 Defined as the value of savings by domestic institutions.
 
Calculated as the value of investment less
    NET trade balance
    NET balance on margin trade
    Depreciation

$offtext

Parameter
 invest(reg)      Value of investment by region
 trade_bal(reg)   Value of trade balance by region
 marg_bal(reg)    Value of margin balance by region
 deprec(reg)      Depreciation by region
 
 
 ;

 invest(reg)     = {SUM[mcc,SAM_gtp(mcc,i_is,reg)]
                     + SUM[ttsm,SAM_gtp(ttsm,i_is,reg)]
                     + SUM[dcc,SAM_gtp(dcc,i_is,reg)]
                     + SUM[ttsd,SAM_gtp(ttsd,i_is,reg)] }  ;
 
 trade_bal(reg)   = SUM[ww,SAM_gtp(i_is,ww,reg)]  ;
                     
 marg_bal(reg)   =  SAM_gtp(i_is,vst_o,reg)
                     + SAM_gtp(i_is,vst_w,reg)
                     + SAM_gtp(i_is,vst_a,reg)  ;
                     
 deprec(reg)     = VDEP(reg)   ;
 
 SAM_gtp(i_is,reg_h,reg)  = invest(reg)
                                  - deprec(reg)
                                  - trade_bal(reg)
                                  - marg_bal(reg) ;

$ontext
 SAM_gtp(i_is,reg_h,reg)  = {SUM[mcc,SAM_gtp(mcc,i_is,reg)]
                                  + SUM[ttsm,SAM_gtp(ttsm,i_is,reg)]
                                  + SUM[dcc,SAM_gtp(dcc,i_is,reg)]
                                  + SUM[ttsd,SAM_gtp(ttsd,i_is,reg)] }
                                  - {SAM_gtp(i_is,"otp_vst",reg)
                                     + SAM_gtp(i_is,"wtp_vst",reg)
                                     + SAM_gtp(i_is,"atp_vst",reg)
                                     + SUM[ww,SAM_gtp(i_is,ww,reg)]
                                     + SUM[ff,SAM_gtp(i_is,ff,reg)]}                                    
  ;
  
$offtext

*#### Computing Account totals for Global SAM by Region

 SAM_gtp(t_tot,ssnp,reg)        = SUM(ssn,SAM_gtp(ssn,ssnp,reg)) ;
 SAM_gtp(ssn,t_tot,reg)         = SUM(ssnp,SAM_gtp(ssn,ssnp,reg)) ;

$offfold 
*############## 8. ANALYSING SAM_gtp #####################################
* This section reports difference & percent differences in row & column totals

$onFold

Set
 step    steps for counts of big total and percentage differences   /
 stgt5        > 5 total OR percentage difference according to case
 stgt1        > 1 total OR percentage difference according to case
 stgt05       > 0.5 total OR percentage difference according to case
 stgt01       > 0.1 total OR percentage difference according to case
 stgt001      > 0.01 total OR percentage difference according to case
 stgt0001     > 0.001 total OR percentage difference according to case
 stgt00001    > 0.0001 total OR percentage difference according to case
 stgt000001   > 0.00001 total OR percentage difference according to case
 stgt0000001  > 0.000001 total OR percentage difference according to case
  /

 case   number of cases in each step  /
 case1      Differences in Account totals
 case2      Differences in Account percentages
 case3      Differences in Account totals AND percentages
  /
  ;

Parameter

 COLTOT(*,reg)       Check on region column totals
 ROWTOT(reg,*)       Check on region row totals
 DIFFTOT(*,reg)      Check on difference in region column and row totals
 BIGDIFFTOT(*,reg)   BIG (>0.01) difference in region column and row totals
 SUMDIFFTOT(reg)     Sum of differences in region row and column totals
 DIFFPER(*,reg)      Percentage differences in region column and row totals
 BIGDIFFPER(*,reg)   BIG (>0.01) Percentage diffs in region column and row totals

 DIFTOTPERCNT(step,case)  Counts of big total and percentage differences

 ;

 COLTOT(ssnp,reg)    = SUM(ssn,SAM_gtp(ssn,ssnp,reg)) ;
 ROWTOT(reg,ssn)     = SUM(ssnp,SAM_gtp(ssn,ssnp,reg)) ;

 DIFFTOT(ssnp,reg)   = COLTOT(ssnp,reg) - ROWTOT(reg,ssnp) ;

 DIFFTOT(ssnp,reg)   = ROUND(DIFFTOT(ssnp,reg),6 ) ;

 BIGDIFFTOT(ssnp,reg)$(ABS(DIFFTOT(ssnp,reg) GT 0.01)) = DIFFTOT(ssnp,reg) ;

 SUMDIFFTOT(reg)     = SUM(ssnp,DIFFTOT(ssnp,reg)) ;

 DIFFPER(ssnp,reg)$COLTOT(ssnp,reg)
       = (DIFFTOT(ssnp,reg)/(0.5 * (COLTOT(ssnp,reg) + ROWTOT(reg,ssnp)))) * 100 ;

 DIFFPER(ssnp,reg)   = ROUND(DIFFPER(ssnp,reg),6 ) ;

 BIGDIFFPER(ssnp,reg)$(ABS(DIFFPER(ssnp,reg) GT 0.01)) = DIFFPER(ssnp,reg) ;

* Counting big total and percentage differences

 DIFTOTPERCNT("stgt5","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 5), 1) ;
 DIFTOTPERCNT("stgt1","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 1), 1) ;
 DIFTOTPERCNT("stgt05","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.5), 1) ;
 DIFTOTPERCNT("stgt01","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.1), 1) ;
 DIFTOTPERCNT("stgt001","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.01), 1) ;
 DIFTOTPERCNT("stgt0001","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.001), 1) ;
 DIFTOTPERCNT("stgt00001","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.0001), 1) ;
 DIFTOTPERCNT("stgt000001","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.00001), 1) ;
 DIFTOTPERCNT("stgt0000001","case1")
                        = SUM((ssn,reg)$(DIFFTOT(ssn,reg) > 0.000001), 1) ;

 DIFTOTPERCNT("stgt5","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 5), 1) ;
 DIFTOTPERCNT("stgt1","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 1), 1) ;
 DIFTOTPERCNT("stgt05","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.5), 1) ;
 DIFTOTPERCNT("stgt01","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.1), 1) ;
 DIFTOTPERCNT("stgt001","case2")
                      = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.01), 1) ;
 DIFTOTPERCNT("stgt0001","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.001), 1) ;
 DIFTOTPERCNT("stgt00001","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.0001), 1) ;
 DIFTOTPERCNT("stgt000001","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.00001), 1) ;
 DIFTOTPERCNT("stgt0000001","case2")
                        = SUM((ssn,reg)$(DIFFPER(ssn,reg) > 0.000001), 1) ;

 DIFTOTPERCNT("stgt5","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 5)
                              AND (DIFFPER(ssn,reg) > 5)), 1) ;
 DIFTOTPERCNT("stgt1","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 1)
                              AND (DIFFPER(ssn,reg) > 1)), 1) ;
 DIFTOTPERCNT("stgt05","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.5)
                              AND (DIFFPER(ssn,reg) > 0.5)), 1) ;
 DIFTOTPERCNT("stgt01","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.1)
                              AND (DIFFPER(ssn,reg) > 0.1)),  1) ;
 DIFTOTPERCNT("stgt001","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.01)
                              AND (DIFFPER(ssn,reg) > 0.01)),  1) ;
 DIFTOTPERCNT("stgt0001","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.001)
                              AND (DIFFPER(ssn,reg) > 0.001)),  1) ;
 DIFTOTPERCNT("stgt00001","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.0001)
                              AND (DIFFPER(ssn,reg) > 0.0001)),  1) ;
 DIFTOTPERCNT("stgt000001","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.00001)
                              AND (DIFFPER(ssn,reg) > 0.00001)),  1) ; ;
 DIFTOTPERCNT("stgt0000001","case3")
                        = SUM((ssn,reg)$((DIFFTOT(ssn,reg) > 0.000001)
                              AND (DIFFPER(ssn,reg) > 0.000001)),  1) ;

option decimals = 6 ;

Execute_Unload  'gtp_output\stats.gdx',
                                       COLTOT
                                       ROWTOT
                                       DIFFTOT
                                       BIGDIFFTOT
                                       SUMDIFFTOT
                                       DIFFPER
                                       BIGDIFFPER
                                       DIFTOTPERCNT
    ;
    
$offFold

*############## 9. OTHER DATA FROM GSDFDAT.GDX ###########################
$onFold

Parameter
 E_EVOS(ff,aa,rr)    After (income) tax value of endowment supply
 F_FBEP(ff,aa,rr)    Gross factor-based subsidy payments
 F_FTRV(ff,aa,rr)    Gross factor employment tax revenue

 S_SAVE(rr)          Saving by region
 V_VKB(rr)           Capital stock by regions

 P_POP(rr)           Population
 ;
 
 E_EVOS(ff,aa,rr)    = SUM[(endw,acts,reg)$(map_ff_endw(ff,endw)
                                           $map_aa_acts(aa,acts)
                                           $map_rr_reg(rr,reg)) ,
                                 EVOS(endw,acts,reg) ] ;
 
 F_FBEP(ff,aa,rr)    = SUM[(endw,acts,reg)$(map_ff_endw(ff,endw)
                                           $map_aa_acts(aa,acts)
                                           $map_rr_reg(rr,reg)) ,
                                 FBEP(endw,acts,reg)  ] ;

 F_FTRV(ff,aa,rr)    = SUM[(endw,acts,reg)$(map_ff_endw(ff,endw)
                                           $map_aa_acts(aa,acts)
                                           $map_rr_reg(rr,reg)) ,
                                 FTRV(endw,acts,reg) ] ;
                                                                                     
 S_SAVE(rr)          = SUM[reg$map_rr_reg(rr,reg),SAVE(reg)] ;
 
 V_VKB(rr)           = SUM[reg$map_rr_reg(rr,reg),VKB(reg)] ;
                                           
 P_POP(rr)           = SUM[reg$map_rr_reg(rr,reg),POP(reg)] ;            
 
$offFold

*############## 10. COMPILING SATELLITE ACCOUNTS #########################
*#### 9a. GTAP DATABASE ELASTICITIES DATA

$onFold

Parameters
* GTAP Parameter data

 ESUBC(acts,reg)     CES elasticity across intermediate inputs
 ESUBD(comm,reg)     CES elasticity between domestic and imported goods
 ESUBG(reg)          Government expenditure CES elasticity
 ESUBI(reg)          Investment expenditure CES elasticity
 ESUBM(comm,reg)     CES elasticity of import demand across source
 ESUBQ(comm,reg)     CES demand elasticity for 'making' commodities
 ESUBS(comm)         CES elasticity across margin suppliers
 ESUBT(acts,reg)     Top level production elasticity
 ESUBVA(acts,reg)    Inter-factor substitution elasticity
 ETRAE(endw,reg)     CET transformation elasticities for factors
 ETRAQ(acts,reg)     CET transformation of domestic production
 INCPAR(comm,reg)    CDE expansion parameter
 
 RORFLEX(reg)        Flexibility of expected net ROR wrt investment
 SUBPAR(comm,reg)    CDE substitution parameter

 ;

$GDXIN GTP_data\%year%\GSDFPAR.gdx

* GTAP parameter Data
$LOADdc ESUBC ESUBD ESUBG ESUBI ESUBM ESUBQ ESUBS ESUBT ESUBVA
$LOADdc ETRAE ETRAQ INCPAR
$LOADdc RORFLEX SUBPAR


$GDXIN

Parameter

* Satellite account data

 E_SUBD(mcc,rr)     Armington CES for domestic_imported allocation
 E_SUBM(mcc,rr)     Armington CES for regional allocation of imports
 
 E_SUBVA(aa,rr)     CES between primary factors in production
 E_SUBT(aa,rr)      Elasticity of intermediate input substitution
 E_SUBC(aa,rr)      CES elasticity across intermediate inputs
 E_TRAE(ff,rr)      CET between sectors for sluggish primary factors
 
 E_SUBQ(dcc,rr)     CES demand elasticity for 'making' commodities
 
 E_SUBCDE(dcc,rr)   CDE substitution parameter
 E_INCCDE(dcc,rr)   CDE expansion parameter


 E_SUBG(rr)         Government expenditure CES elasticity
 E_SUBI(rr)         Investment expenditure CES elasticity
 
 RFLX(rr)           Expected rate of return flexibility parameter

   ;
   
* Assigning elasticities
                   
 E_SUBD(mcc,rr)   = SUM[(comm,reg)$(map_mcc_comm(mcc,comm)
                                    $map_rr_reg(rr,reg)),
                                    ESUBD(comm,reg)] ;
                   
 E_SUBM(mcc,rr)   = SUM[(comm,reg)$(map_mcc_comm(mcc,comm)
                                    $map_rr_reg(rr,reg)),
                                     ESUBM(comm,reg)] ;
                          
 E_SUBVA(aa,rr)   = SUM[(acts,reg)$(map_aa_acts(aa,acts)
                                   $map_rr_reg(rr,reg)),
                                    ESUBVA(acts,reg)] ;

 E_SUBT(aa,rr)    = SUM[(acts,reg)$(map_aa_acts(aa,acts)
                                   $map_rr_reg(rr,reg)),
                                    ESUBT(acts,reg)] ;
                         
 E_SUBC(aa,rr)    = SUM[(acts,reg)$(map_aa_acts(aa,acts)
                                   $map_rr_reg(rr,reg)),
                                   ESUBC(acts,reg)] ;
                        
 E_TRAE(ff,rr)    = SUM[(endw,reg)$(map_ff_endw(ff,endw)
                                   $map_rr_reg(rr,reg)),
                                   ETRAE(endw,reg) ] ;
                         
 E_SUBQ(dcc,rr)   = SUM[(comm,reg)$(map_dcc_comm(dcc,comm)
                                   $map_rr_reg(rr,reg)),
                                    ESUBQ(comm,reg) ] ;

 E_SUBCDE(dcc,rr) = SUM[(comm,reg)$(map_dcc_comm(dcc,comm)
                                   $map_rr_reg(rr,reg)),
                                   SUBPAR(comm,reg)] ;

 E_INCCDE(dcc,rr) = SUM[(comm,reg)$(map_dcc_comm(dcc,comm)
                                   $map_rr_reg(rr,reg)),
                                  INCPAR(comm,reg)] ;
                        
 E_SUBG(rr)       = SUM[reg$map_rr_reg(rr,reg),ESUBG(reg)] ;
 E_SUBI(rr)       = SUM[reg$map_rr_reg(rr,reg),ESUBI(reg)] ;
               
 RFLX(rr)         = SUM[reg$map_rr_reg(rr,reg),RORFLEX(reg)] ;
 
$offFold

*#### 9b. GTAP ENERGY VOLUME DATA

$onFold

Parameters
* GTAP Parameter data

* Energy volume use

 EDF(erg,acts,reg)       true Usage of domestic products by firm
 EDG(erg,reg)            Public consumption of domestic goods
 EDI(erg,reg)            Investment consumption of domestic goods
 EDP(erg,reg)            Private consumption of domestic goods
 EMF(erg,acts,reg)       Usage of imported products by firm
 EMG(erg,reg)            Public consumption of imported goods
 EMI(erg,reg)            Investment consumption of imported goods
 EMP(erg,reg)            Private consumption of imported goods
 EXI(erg,src,dst)        Private consumption of imported goods

 ;

$GDXIN GTP_data\%year%\GSDFVOLE.gdx
* Energy volumen use

$LOADdc EDF EDG EDI EDP EMF EMG EMI EMP
$LOADdc EXI

$GDXIN

Parameter
* SAM Satelitte Data

 E_VolD(dcc,ss,rr)          volume of input domestic purchases by agents (toe)
 E_VolM(mcc,ss,rr)          volume of input import purchases by agents (toe)

 E_VolT_A(mcc,src,dst)      volume of bilateral trade (toe)
 E_VolT_B(mcc,rr,dst)      volume of bilateral trade (toe)
 
 E_VolT(mcc,rr,rr)          volume of bilateral trade (toe)

* Total Volumes for checking

 TOT_EVolD(rr)             volume of input domestic purchases by agents (toe)
 TOT_EVolM(rr)             volume of input import purchases by agents (toe)
 TOT_EVol(rr)              volume of input AGGREGATE purchases by agents (toe)

 TOT_EVolT(rr)             volume of bilateral trade (toe)
 TOT_EVol_IMP(rr)          volume of bilateral trade (toe)

   ;
   
* Assigning Energy Volumes
   
 E_VolD(dcc,aa,rr)    = SUM[(erg,acts,reg)
                           $(map_dcc_comm(dcc,erg)
                            $map_aa_acts(aa,acts)
                            $map_rr_reg(rr,reg)),
                             EDF(erg,acts,reg)] ;
                             
 E_VolD(dcc,h_h,rr)   = SUM[(erg,reg)$(map_dcc_comm(dcc,erg)
                                       $map_rr_reg(rr,reg)),
                                       EDP(erg,reg)] ;
                                 
 E_VolD(dcc,g_t,rr)   = SUM[(erg,reg)$(map_dcc_comm(dcc,erg)
                                       $map_rr_reg(rr,reg)),
                                        EDG(erg,reg)] ;
                                 
 E_VolD(dcc,i_is,rr)  = SUM[(erg,reg)$(map_dcc_comm(dcc,erg)
                                     $map_rr_reg(rr,reg)),
                                     EDI(erg,reg)] ;
                               
*Import purchases

 E_VolM(mcc,aa,rr)    = SUM((erg,acts,reg)
                           $(map_mcc_comm(mcc,erg)
                            $map_aa_acts(aa,acts)
                            $map_rr_reg(rr,reg)),
                             EMF(erg,acts,reg)) ;

 E_VolM(mcc,h_h,rr)   = SUM[(erg,reg)$(map_mcc_comm(mcc,erg)
                                      $map_rr_reg(rr,reg)),
                                      EMP(erg,reg)] ;
                                 
 E_VolM(mcc,g_t,rr)   = SUM[(erg,reg)$(map_mcc_comm(mcc,erg)
                                      $map_rr_reg(rr,reg)),
                                      EMG(erg,reg)] ;
                                 
 E_VolM(mcc,i_is,rr)  = SUM[(erg,reg)$(map_mcc_comm(mcc,erg)
                                       $map_rr_reg(rr,reg)),
                                       EMI(erg,reg)] ; 

* Trade Volumes
 E_VolT_A(mcc,src,dst)   = SUM[erg$map_mcc_comm(mcc,erg),
                                 EXI(erg,src,dst)] ;
                                                                 
 E_VolT_B(mcc,rr,dst)   = SUM[src$map_rr_reg(rr,src),
                                            E_VolT_A(mcc,src,dst)] ;
                                            
 E_VolT(mcc,rr,rrp)     = SUM[dst$map_rr_reg(rrp,dst),
                                            E_VolT_B(mcc,rr,dst)] ;
                                 
$offFold

*#### 9c. GTAP EMISSIONS DATA

$onFold

Parameters

* GTAP CO2 emissions

 MDF(erg,acts,reg)  Emisssions from domestic product in current production  Mt CO2
 MDG(erg,reg)       Emisssions from domestic product in current consumption Mt CO2
 MDI(erg,reg)       Emisssions from domestic product in current consumption Mt CO2
 MDP(erg,reg)       Emisssions from domestic product in current consumption Mt CO2
     
 MMF(erg,acts,reg)  Emisssions from imported product in current production  Mt CO2
 MMG(erg,reg)       Emisssions from imported product in current consumption Mt CO2
 MMI(erg,reg)       Emisssions from imported product in current consumption Mt CO2
 MMP(erg,reg)       Emisssions from imported product in current consumption Mt CO2

* GTAP NON CO2 emissions

 EMI_ENDW(em,endw,acts,reg)      Endowment based emissions mmt
 EMI_HH(em,comm,reg)             Private-based emissions mmt
 
 EMI_IO(em,comm,acts,reg)        IO-based non-CO2 emissions mmt
 EMI_IOP(em,comm,acts,reg)       IO-based process emissions mmt
 EMI_LU(em,lu_cat,lu_subcat,reg) Land-use emissions mmt
 EMI_QO(em,acts,reg)             Output-based emissions mmt
 GWP(ghg,reg,ar)                 Global warming potential

 ;

$GDXIN GTP_data\%year%\GSDFEMISS.gdx

* CO2 Emissions Data
$LOADdc MDF MDG MDI MDP
$LOADdc MMF MMG MMI MMP

$GDXIN 

$GDXIN GTP_data\%year%\GSDFNCO2.gdx

* Non CO2 Emissions Data
$LOADdc EMI_ENDW  EMI_HH EMI_IO EMI_IOP EMI_LU EMI_QO GWP


$GDXIN

Parameter

* ~~~~ Satellite account data
* GHG Emissions
 EMIT_CO2(ss,ss,rr)           CO2 emissions 
 
* NON GHG Emissions
 EMIT_NGHG(ghgn,ss,ss,rr)     NON  GHG emissions on commodity accounts
 
* Emissions
 EMIT(em,ss,ss,rr)            ALL emissions on commodity accounts
 
* Land Use Emissions
 EMIT_LU(em,lu_cat,lu_subcat,rr)        LAND USE emissions
 
 ;
 
*~~~~ CO2 emissions

 EMIT_CO2(dcc,aa,rr) = SUM[(fuel,acts,reg)
                            $(map_dcc_comm(dcc,fuel)
                              $map_aa_acts(aa,acts)
                              $map_rr_reg(rr,reg)),
                               MDF(fuel,acts,reg)] ;
                         
 EMIT_CO2(dcc,g_t,rr) = SUM[(fuel,reg)$(map_dcc_comm(dcc,fuel)
                                       $map_rr_reg(rr,reg)),
                                        MDG(fuel,reg)] ;
                        
 EMIT_CO2(dcc,i_is,rr) = SUM[(fuel,reg)$(map_dcc_comm(dcc,fuel)
                                         $map_rr_reg(rr,reg)),
                                          MDI(fuel,reg)] ;
                       
 EMIT_CO2(dcc,h_h,rr) = SUM[(fuel,reg)$(map_dcc_comm(dcc,fuel)
                                        $map_rr_reg(rr,reg)),
                                          MDP(fuel,reg)] ;
                              
 EMIT_CO2(mcc,aa,rr) = SUM[(fuel,acts,reg)
                           $(map_mcc_comm(mcc,fuel)
                            $map_aa_acts(aa,acts)
                            $map_rr_reg(rr,reg)),
                              MMF(fuel,acts,reg)] ;
                         
 EMIT_CO2(mcc,g_t,rr) = SUM[(fuel,reg)$(map_mcc_comm(mcc,fuel)
                                       $map_rr_reg(rr,reg)),
                                       MMG(fuel,reg)] ;
                        
 EMIT_CO2(mcc,i_is,rr) = SUM[(fuel,reg)$(map_mcc_comm(mcc,fuel)
                                        $map_rr_reg(rr,reg)),
                                         MMI(fuel,reg)] ;
                       
 EMIT_CO2(mcc,h_h,rr) = SUM[(fuel,reg)$(map_mcc_comm(mcc,fuel)
                                        $map_rr_reg(rr,reg)),
                                        MMP(fuel,reg)] ;
                               
 EMIT_CO2(cc,ss,rr)    = SUM[mcc$map_cc_mcc(cc,mcc),EMIT_CO2(mcc,ss,rr)]
                         + SUM[dcc$map_cc_dcc(cc,dcc),EMIT_CO2(dcc,ss,rr)] ;
                               

* Emissions
 EMIT(em,cc,aa,rr)       = SUM[(comm,acts,reg)
                                $(map_cc_comm(cc,comm)
                                  $map_aa_acts(aa,acts)
                                  $map_rr_reg(rr,reg)),
                                   EMI_IO(em,comm,acts,reg)] ;
                                   
 EMIT(em,cc,aa,rr)       = EMIT(em,cc,aa,rr)
                                 + (SUM[(comm,acts,reg)
                                    $(map_cc_comm(cc,comm)
                                      $map_aa_acts(aa,acts)
                                      $map_rr_reg(rr,reg)),
                                       EMI_IOP(em,comm,acts,reg)]) ;
                                                                             
 EMIT(em,cc,h_h,rr)   = SUM[(comm,reg)$(map_cc_comm(cc,comm)
                                        $map_rr_reg(rr,reg)),
                                         EMI_HH(em,comm,reg)] ;
                                   
 EMIT(em,ff,aa,rr)      = SUM[(endw,acts,reg)
                                $(map_ff_endw(ff,endw)
                                  $map_aa_acts(aa,acts)
                                  $map_rr_reg(rr,reg)),
                                  EMI_ENDW(em,endw,acts,reg)] ;
                              
 EMIT(em,"tots",aa,rr)  = SUM[(acts,reg)$(map_aa_acts(aa,acts)
                                         $map_rr_reg(rr,reg)),
                                         EMI_QO(em,acts,reg)] ;
                                      
* Including CO2 emissions in EMIT

 EMIT("co2",dcc,ss,rr)       =  EMIT("co2",dcc,ss,rr) + EMIT_CO2(dcc,ss,rr) ;
 EMIT("co2",mcc,ss,rr)       =  EMIT("co2",mcc,ss,rr) + EMIT_CO2(mcc,ss,rr) ;
 EMIT("co2",cc,ss,rr)        =  EMIT("co2",cc,ss,rr) + EMIT_CO2(cc,ss,rr) ;
                                                                         
*~~~~ Land Use Emissions

 EMIT_LU(em,lu_cat,lu_subcat,rr)      = SUM[reg$map_rr_reg(rr,reg),
                                         EMI_LU(em,lu_cat,lu_subcat,reg)] ;

$offFold

*############## 11. REMOVING REG AND USING RR ##########################
$onfold
Parameter
 SAMG_gtp(ss,ss,rr)         Global GTAP SAMG
 
;

 
 SAMG_gtp(ss,ssp,rr)  = SUM[reg$map_rr_reg(rr,reg),SAM_gtp(ss,ssp,reg)] ;

$offfold
*############## 12. WRITING GTAP DATABASE 11 TO GDX #####################

$onfold
$onText
    The data written to GDX include information that is needed for the
  generate of databases for the ANARRES/GLOBE model families. Some of
  these data may not be of use for other purposes.
$offText

Execute_Unload  'gtp_output\%data_out%.gdx',
* SAM and associated sets
                                    SAMG_gtp
                                    
                                    ss   
                                    mcc
                                    dcc
                                    cc
                                    aa                                   
                                    ff
                                    ll                                   
                                    ttm
                                    ttms
                                    tte
                                    tts
                                    ttsm
                                    ttsd
                                    ttff                                
                                    ootpm
                                    wwtpm
                                    aatpm
                                    vvst
                                    ii
                                    ww
                                    rr
                                    reg
                                    
                                    cc_e
                                    mcc_e
                                    dcc_e
                                    tts_e
                                    ttsd_e
                                    ttsm_e
                                    
                                    em
                                    ghg
                                    ghgn
                                    ghgnco2
                                    fgas
                                    lu_cat
                                    lu_subcat
                                    ar
                                    step
                                    case
                                    
* GTAP Base Sets
        acts      
        comm      
        endw      
        marg      
*        c         
        reg       
        map_reg_c
        tartype
        samac     
*        Energy
        erg
        fuel 
*        Emissions
*        em        
*        ghg  
*        ghgn  
*        fgas  
        emnco2
*        ghgnco2
*        lu_cat    
*        lu_subcat 
*        ar        
 

*~~~~~ Satellite Accounts
* Other base data
                                    E_EVOS
                                    F_FBEP
                                    F_FTRV
                                    S_SAVE
                                    V_VKB
                                    P_POP
* Elasticities
                                   E_SUBD
                                   E_SUBM
                                   E_SUBVA
                                   E_SUBT
                                   E_SUBC
                                   E_TRAE
                                   E_SUBQ
                                   E_SUBCDE
                                   E_INCCDE
                                   E_SUBG
                                   E_SUBI
                                   RFLX
* Energy volumes
                                   E_VolD
                                   E_VolM
                                   E_VolT
* Emissions
                                   EMIT_CO2
                                   EMIT
                                   EMIT_LU
 ;
 
$offfold

*########################### THE END ########################
